--[[
This addon for WoW will play a music file when you start to dance. The files have to 
be placed in the "Music" folder of the addon. The file that is played has te be 
named "<race><gender>.mp3". So for the song to play for human males the filename 
would be "HumanMale.mp3"
]]--

-- Save variables, these will get overwritten during load time with the stored value
DanceMusic_Enabled = true;

-- Global var so it can be toggled with myDebug addon
DanceMusicDebug = false;

local DanceMusic_Playing = false;
local genders = { "Unknown", "Male", "Female" };

function DanceMusic_Debug(msg)
  if DanceMusicDebug then
    DEFAULT_CHAT_FRAME:AddMessage(msg);
  end;
end

function DanceMusic_SlashCommandHandler(command)
	if (command == "on") then
		DanceMusic_Enabled = true;
		DEFAULT_CHAT_FRAME:AddMessage(DANCEMUSIC_ENABLED);
	elseif (command == "off") then
		DanceMusic_Enabled = false;
		DEFAULT_CHAT_FRAME:AddMessage(DANCEMUSIC_DISABLED);
	else
		if (DanceMusic_Enabled) then
			DEFAULT_CHAT_FRAME:AddMessage(DANCEMUSIC_ENABLED);
		else
			DEFAULT_CHAT_FRAME:AddMessage(DANCEMUSIC_DISABLED);
		end;

		DEFAULT_CHAT_FRAME:AddMessage(DANCEMUSIC_HELP);
end;
	end;

function DanceMusic_OnLoad()
	-- Register the slash command
	SlashCmdList["DanceMusic"] = DanceMusic_SlashCommandHandler;
	SLASH_DanceMusic1 = "/dancemusic";

	-- Hook into the DoEmote function to see if we start dancing
	hooksecurefunc("DoEmote", DanceMusic_DoEmote);

	-- Dance stops when moving, so hook relevant movement functions to stop the music. 
	hooksecurefunc("MoveForwardStart" , DanceMusic_StopMusic);
	hooksecurefunc("MoveBackwardStart", DanceMusic_StopMusic);
	hooksecurefunc("StrafeLeftStart"  , DanceMusic_StopMusic);
	hooksecurefunc("StrafeRightStart" , DanceMusic_StopMusic);
	hooksecurefunc("JumpOrAscendStart", DanceMusic_StopMusic);

	DanceMusic_Debug('DanceMusic_OnLoad');
end

function DanceMusic_DoEmote(emote, msg)
	DanceMusic_Debug('DanceMusic_DoEmote '..emote);

	--emote is DANCE when "/dance" is used.
	if (DanceMusic_Enabled and emote=="DANCE") then
		local _, songname = UnitRace("player");

		-- Undead are called Scourge, fix it to Undead
		if (songname=='Scourge') then
			songname = 'Undead';
		end;
		
		-- Add the gender and .mp3 extension
		songname = songname..genders[UnitSex("player")]..'.mp3';

		-- Play the song
		DanceMusic_Debug('Start song: '..songname);
		PlayMusic('Interface\\AddOns\\DanceMusic\\Music\\'..songname);
		DanceMusic_Playing = true;
	end;
end

-- Stop the music
function DanceMusic_StopMusic()
	-- Only stop the music when DanceMusic was playing
	DanceMusic_Debug('Stop song when playing');

	if (DanceMusic_Playing) then
		StopMusic();
		DanceMusic_Playing = false;
		DanceMusic_Debug('Song is stopped');
	end;
end;
